Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckProcessIdentity ¶
CheckProcessIdentity verifies that a process with the given PID is still alive and optionally matches the expected command name (to detect PID reuse).
func GetProcessAttributes ¶
func GetProcessAttributes() *syscall.SysProcAttr
GetProcessAttributes returns process attributes for Unix systems.
func GetProcessCommand ¶
GetProcessCommand returns the command name for a given PID. Returns empty string if the process cannot be found.
func GetShutdownSignals ¶
GetShutdownSignals returns the signals to listen for graceful shutdown on Unix systems
func TerminateProcess ¶
TerminateProcess sends SIGTERM to a process on Unix systems.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.